@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2016, Freja Nordsiek
+# Copyright (c) 2013-2023, Freja Nordsiek
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -1464,18 +1464,18 @@ class PythonScalarMarshaller(NumpyScalarArrayMarshaller):
 
         # The type string determines how to convert it back to a Python
         # type (just look up the entry in types). As it might be
-        # returned as an ndarray, it needs to be run through
-        # np.asscalar. Now, since int and long are unified in Python 3.x
-        # and the size of int in Python 2.x is not always the same, if
-        # the type_string is 'int', then we need to check to see if it
-        # can fit into an int if we are in Python 2.x. If it will fit,
-        # it is returned as an int. If it would not fit, it is returned
-        # as a long.
+        # returned as an ndarray, we just need to use the item
+        # method. Now, since int and long are unified in Python 3.x and
+        # the size of int in Python 2.x is not always the same, if the
+        # type_string is 'int', then we need to check to see if it can
+        # fit into an int if we are in Python 2.x. If it will fit, it is
+        # returned as an int. If it would not fit, it is returned as a
+        # long.
         type_string = get_attribute_string(grp[name], 'Python.Type')
         if type_string in self.python_type_strings:
             tp = self.types[self.python_type_strings.index(
                             type_string)]
-            sdata = np.asscalar(data)
+            sdata = data.item()
             if sys.hexversion >= 0x03000000 or tp != int:
                 return tp(sdata)
             else:
