@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2016, Freja Nordsiek
+# Copyright (c) 2013-2023, Freja Nordsiek
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -28,11 +28,11 @@ This is the hdf5storage package, a Python package to read and write
 python data types to HDF5 (Heirarchal Data Format) files beyond just
 Numpy types.
 
-Version 0.1.18
+Version 0.1.19
 
 """
 
-__version__ = "0.1.18"
+__version__ = "0.1.19"
 
 import sys
 import os
@@ -901,7 +901,8 @@ class MarshallerCollection(object):
         # the classes) by inspection.
         self._builtin_marshallers = [m() for key, m in dict(
                                      inspect.getmembers(Marshallers,
-                                     inspect.isclass)).items()]
+                                     inspect.isclass)).items()
+                                     if m != Marshallers.parse_version]
         self._user_marshallers = []
 
         # A list of all the marshallers will be needed along with
@@ -1271,8 +1272,12 @@ def writes(mdict, filename='data.h5', truncate_existing=False,
 
         s = 'MATLAB 7.3 MAT-file, Platform: CPython ' \
             + '{0}.{1}.{2}'.format(v['major'], v['minor'], v['micro']) \
-            + ', Created on: ' \
-            + now.strftime('%a %b %d %H:%M:%S %Y') \
+            + ', Created on: {0} {1}'.format(
+            ('Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun')[ \
+            now.weekday()], \
+            ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', \
+             'Sep', 'Oct', 'Nov', 'Dec')[now.month - 1]) \
+            + now.strftime(' %d %H:%M:%S %Y') \
             + ' HDF5 schema 1.00 .'
 
         # Make the bytearray while padding with spaces up to 128-12
