@@ -224,6 +224,75 @@ class TestPythonMatlabFormat(object):
                                   self.options)
         self.assert_equal(out, data)
 
+    def check_numpy_sized_dtype_nested_0(self, zero_shaped):
+        dtypes = ('uint8', 'uint16', 'uint32', 'uint64',
+                  'int8', 'int16', 'int32', 'int64',
+                  'float32', 'float64',
+                  'complex64', 'complex128')
+        for i in range(10):
+            dt = (random.choice(dtypes), (2, 2 * zero_shaped))
+            data = np.zeros((2, ), dtype=dt)
+            out = self.write_readback(data, random_name(),
+                                      self.options)
+            self.assert_equal(out, data)
+
+    def check_numpy_sized_dtype_nested_1(self, zero_shaped):
+        dtypes = ('uint8', 'uint16', 'uint32', 'uint64',
+                  'int8', 'int16', 'int32', 'int64',
+                  'float32', 'float64',
+                  'complex64', 'complex128')
+        for i in range(10):
+            dt = [('a', random.choice(dtypes), (1, 2)),
+                  ('b', random.choice(dtypes), (1, 1, 4 * zero_shaped)),
+                  ('c',
+                   [('a', random.choice(dtypes)),
+                    ('b', random.choice(dtypes), (1, 2))])]
+            data = np.zeros((random.randrange(1, 4), ), dtype=dt)
+            out = self.write_readback(data, random_name(),
+                                      self.options)
+            self.assert_equal(out, data)
+
+    def check_numpy_sized_dtype_nested_2(self, zero_shaped):
+        dtypes = ('uint8', 'uint16', 'uint32', 'uint64',
+                  'int8', 'int16', 'int32', 'int64',
+                  'float32', 'float64',
+                  'complex64', 'complex128')
+        for i in range(10):
+            dt = [('a', random.choice(dtypes), (1, 3)),
+                  ('b',
+                   [('a', random.choice(dtypes), (2, )),
+                    ('b', random.choice(dtypes), (1, 2, 1))]),
+                  ('c',
+                   [('a', random.choice(dtypes),
+                     (3 * zero_shaped, 1)),
+                    ('b', random.choice(dtypes), (2, ))], (2, 1))]
+            data = np.zeros((2, ), dtype=dt)
+            out = self.write_readback(data, random_name(),
+                                      self.options)
+            self.assert_equal(out, data)
+
+    def check_numpy_sized_dtype_nested_3(self, zero_shaped):
+        dtypes = ('uint8', 'uint16', 'uint32', 'uint64',
+                  'int8', 'int16', 'int32', 'int64',
+                  'float32', 'float64',
+                  'complex64', 'complex128')
+        for i in range(10):
+            dt = [('a', random.choice(dtypes), (3, 2)),
+                  ('b',
+                   [('a',
+                     [('a', random.choice(dtypes))],
+                     (2, 2)),
+                    ('b', random.choice(dtypes), (1, 2))]),
+                  ('c',
+                   [('a',
+                     [('a', random.choice(dtypes),
+                       (2, 1, zero_shaped * 2))]),
+                    ('b', random.choice(dtypes))])]
+            data = np.zeros((1, ), dtype=dt)
+            out = self.write_readback(data, random_name(),
+                                      self.options)
+            self.assert_equal(out, data)
+
     def check_python_collection(self, tp, same_dims):
         # Makes a random collection of the specified type, writes it and
         # reads it back, and then compares it.
@@ -513,6 +582,22 @@ class TestPythonMatlabFormat(object):
         for n in range(1, 10):
             yield self.check_numpy_chararray_empty, n
 
+    def test_numpy_sized_dtype_nested_0(self):
+        for zero_shaped in (False, True):
+            yield self.check_numpy_sized_dtype_nested_0, zero_shaped
+
+    def test_numpy_sized_dtype_nested_1(self):
+        for zero_shaped in (False, True):
+            yield self.check_numpy_sized_dtype_nested_1, zero_shaped
+
+    def test_numpy_sized_dtype_nested_2(self):
+        for zero_shaped in (False, True):
+            yield self.check_numpy_sized_dtype_nested_2, zero_shaped
+
+    def test_numpy_sized_dtype_nested_3(self):
+        for zero_shaped in (False, True):
+            yield self.check_numpy_sized_dtype_nested_3, zero_shaped
+
     def test_python_collection(self):
         for tp in (list, tuple, set, frozenset, collections.deque):
             yield self.check_python_collection, tp, 'same-dims'
